local GreatLadder = ...

-- Register great ladder prefab nodes
GreatLadder:registerAssetId("models/greatLadder3.fbx/Prefab/greatLadder/CenterPart", _BridgePrefix .. "_CENTER_PREFAB")
GreatLadder:registerAssetId("models/greatLadder3.fbx/Prefab/greatLadder/RootPart", _BridgePrefix .. "_CENTER_ROOT_PREFAB")
GreatLadder:registerAssetId("models/greatLadder3.fbx/Prefab/greatLadder/TilingPart", _BridgePrefix .. "_TILING_PREFAB")

--------------------------------------------------------------------------
-- Register bridge tiling (the pillar part that extends to the ground)
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = _BridgePrefix .. "_TILING_PART",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = _BridgePrefix .. "_TILING_PREFAB"
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 0 }
		}
	}
})

function registerExtremity(_nameFbx, _extremity, _upperAttachType, _lowerAttachType)
    GreatLadder:registerAssetId("models/greatLadder3.fbx/Prefab/greatLadder/" .. _nameFbx .. "SlopePart", _BridgePrefix .. "_SLOPE_" .. _extremity .. "_PREFAB")
    GreatLadder:registerAssetId("models/greatLadder3.fbx/Prefab/greatLadder/" .. _nameFbx .. "Part", _BridgePrefix .. "_" .. _extremity .. "_PREFAB")

    -- Register bridge extremity part
    GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = _BridgePrefix .. "_" .. _extremity .. "_PART",
        Name = _BridgePrefix .. "_" .. _extremity .. "_NAME",
        BuildingZone = _BridgeBuildingZone,
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SLOPE",
		CoreObjectPrefab = _BridgePrefix .. "_" .. _extremity .. "_PREFAB",
		SlopePartList = {
			_BridgePrefix .. "_SLOPE_" .. _extremity .. "_PART"
		},
		CoreBasementPartList = {
			_BridgePrefix .. "_TILING_PART"
		},
		UpperAttachType = _upperAttachType,
		LowerAttachType = _lowerAttachType
        },
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 5 }
		}
	}
    })

    -- Register bridge extremity slope part
    GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = _BridgePrefix .. "_SLOPE_" .. _extremity .. "_PART",
        Name = _BridgePrefix .. "_SLOPE_" .. _extremity .. "_NAME",
        BuildingZone = _BridgeBuildingZone,
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BASEMENT",
		CoreObjectPrefab = _BridgePrefix .. "_SLOPE_" .. _extremity .. "_PREFAB",
		FillerList = {
			_BridgePrefix .. "_TILING_PART"
		}
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 1 }
		}
	}
    })
end

registerExtremity("Start", "START", ATTACH_NODE_TYPE.RIGHT, ATTACH_NODE_TYPE.LEFT)
registerExtremity("End", "END", ATTACH_NODE_TYPE.LEFT, ATTACH_NODE_TYPE.RIGHT)

-- Register bridge center top part
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = _BridgePrefix .. "_CENTER_TOP_PART",
        BuildingZone = _BridgeBuildingZone,
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = _BridgePrefix .. "_CENTER_PREFAB"
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 0 }
		}
	}
})

-- Register the center root part (the scalable part that places multiple center top parts)
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = _BridgePrefix .. "_CENTER_CORE_PART",
        BuildingZone = _BridgeBuildingZone,
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER",
		CoreObjectPrefab = _BridgePrefix .. "_CENTER_ROOT_PREFAB",
		EndPart = _BridgePrefix .. "_CENTER_TOP_PART",
		FillerList = {
			_BridgePrefix .. "_TILING_PART"
		}
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 0 }
		}
	}
})

-- Register the core part (the part with the bridge mover)
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = _BridgePrefix .. "_CORE_PART",
	Name = _BridgePrefix .. "_CORE_NAME",
	Description = _BridgePrefix .. "_CORE_DESC",
	Category = "CORE",
        BuildingZone = _BridgeBuildingZone,
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BRIDGE",
		StartPart = _BridgePrefix .. "_START_PART",
		EndPart = _BridgePrefix .. "_END_PART",
		FillerList = {
			_BridgePrefix .. "_CENTER_CORE_PART"
		},
		MinimumScale = 0,
                MinimumHeightAboveGround = 0  
	},
	AssetBuildingFunction = _BridgePrefix .. "_FUNCTION"
})
GreatLadder:register({
		DataType = "BUILDING_FUNCTION_BRIDGE",
                Id = _BridgePrefix .. "_FUNCTION"
})

GreatLadder:configurePrefabFlagList("models/greatLadder3.fbx/Prefab/greatLadder/CenterPart", { "BRIDGE" })
GreatLadder:configurePrefabFlagList("models/greatLadder3.fbx/Prefab/greatLadder/StartPart", { "BRIDGE" })
GreatLadder:configurePrefabFlagList("models/greatLadder3.fbx/Prefab/greatLadder/EndPart", { "BRIDGE" })
GreatLadder:configurePrefabFlagList("models/greatLadder3.fbx/Prefab/greatLadder/StartSlopePart", { "BRIDGE" })
GreatLadder:configurePrefabFlagList("models/greatLadder3.fbx/Prefab/greatLadder/EndSlopePart", { "BRIDGE" })
